/* 
 * Adminita Actions Bar Fix
 * Add this to your adminita CSS or include it separately
 * This styles Django's default admin_actions template output
 */

/* Actions container styling */
#changelist-form .actions {
  display: flex;
  align-items: center;
  gap: 0.75rem;
  padding: 0.75rem 1.5rem;
  border-bottom: 1px solid rgb(229, 231, 235);
  background-color: rgb(249, 250, 251);
}

.dark #changelist-form .actions {
  border-color: rgb(55, 65, 81);
  background-color: rgb(31, 41, 55);
}

/* Style the action select dropdown */
#changelist-form .actions select {
  padding: 0.5rem 2rem 0.5rem 0.75rem;
  border: 1px solid rgb(209, 213, 219);
  border-radius: 0.5rem;
  background-color: white;
  font-size: 0.875rem;
  color: rgb(17, 24, 39);
  cursor: pointer;
  appearance: none;
  background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 20 20'%3e%3cpath stroke='%236b7280' stroke-linecap='round' stroke-linejoin='round' stroke-width='1.5' d='M6 8l4 4 4-4'/%3e%3c/svg%3e");
  background-position: right 0.5rem center;
  background-repeat: no-repeat;
  background-size: 1.25rem;
}

.dark #changelist-form .actions select {
  border-color: rgb(75, 85, 99);
  background-color: rgb(55, 65, 81);
  color: rgb(243, 244, 246);
}

#changelist-form .actions select:focus {
  outline: none;
  border-color: rgb(59, 130, 246);
  box-shadow: 0 0 0 2px rgba(59, 130, 246, 0.2);
}

/* Style the Go button */
#changelist-form .actions button[type="submit"],
#changelist-form .actions input[type="submit"] {
  padding: 0.5rem 1rem;
  background-color: rgb(75, 85, 99);
  color: white;
  border: none;
  border-radius: 0.5rem;
  font-size: 0.875rem;
  font-weight: 500;
  cursor: pointer;
  transition: background-color 0.15s;
}

#changelist-form .actions button[type="submit"]:hover,
#changelist-form .actions input[type="submit"]:hover {
  background-color: rgb(55, 65, 81);
}

/* Selection counter */
#changelist-form .actions .action-counter {
  font-size: 0.875rem;
  color: rgb(107, 114, 128);
}

.dark #changelist-form .actions .action-counter {
  color: rgb(156, 163, 175);
}

/* Question/help text in actions */
#changelist-form .actions span.question {
  display: none;
}

/* All/Clear selection links */
#changelist-form .actions span.all,
#changelist-form .actions span.clear {
  font-size: 0.875rem;
  color: rgb(59, 130, 246);
  cursor: pointer;
}

#changelist-form .actions span.all:hover,
#changelist-form .actions span.clear:hover {
  text-decoration: underline;
}